@@ -22,17 +22,19 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 
 '''
-import os
-import collections
-import jinja2
-import sys
 import codecs
-
-from typing import Any, Dict, Union, Optional
-from buildtools.bt_logging import log, NullIndenter
-from buildtools.os_utils import ensureDirExists
+import collections
 import fnmatch
+import os
+import sys
+from typing import Any, Dict, Optional, Union
+
+import jinja2
+
+from buildtools.bt_logging import NullIndenter, log
 from buildtools.ext.salt.jinja_ext import salty_jinja_envs
+from buildtools.os_utils import ensureDirExists
+
 
 def delimget(cfg, key, default=None, delim='.'):
     parts = key.split(delim)
