@@ -20,84 +20,81 @@ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
-
 '''
+
+import argparse
 import codecs
 import logging
 import os
-import re
-import sys
 import shutil
-import argparse
+import sys
 import traceback
+from typing import Dict, List, Optional
+
+from ruamel.yaml import YAML
 
 from buildtools import os_utils
 from buildtools.bt_logging import log
 from buildtools.maestro.base_target import BuildTarget
-from buildtools.maestro.utils import (SerializableFileLambda,
-                                      SerializableLambda)
-
-from ruamel.yaml import YAML
-from typing import Dict, List
+from buildtools.maestro.utils import SerializableFileLambda, SerializableLambda
 
 yaml = YAML(typ='safe', pure=True)
 
 yaml.register_class(SerializableLambda)
 yaml.register_class(SerializableFileLambda)
 
+
 class TarjanGraphVertex(object):
     def __init__(self, ID: int, refs: List[int]):
-        self.id=ID
-        self.refs = refs
-        self.disc = -1
-        self.low = -1
-        self.stackMember = False
+        self.id: int = ID
+        self.refs: List[int] = refs
+        self.disc: int = -1
+        self.low: int = -1
+        self.stackMember: bool = False
 
 
-class TarjanGraph(object):
+class TarjanGraph:
     def __init__(self):
-        self.cur_id = 0 # Used for populating the graph.
-        #self.graph = defaultdict(list)
-        self.vertices = {}
-        self.time = 0
-        self.cycles=[]
+        self.cur_id: int = 0  # Used for populating the graph.
+        self.vertices: Dict[int, TarjanGraphVertex] = {}
+        self.time: int = 0
+        self.cycles: List[List[int]] = []
 
     def add_edge(self, ID: int, refs: List[int]):
         self.vertices[ID] = TarjanGraphVertex(ID, refs)
-        #for ref in refs:
-        #    self.graph[ID].append(ref)
 
-    def _sccutil(self, vertex, stack):
+    def _sccutil(self, vertex: TarjanGraphVertex, stack: List[int]):
         vertex.disc = self.time
         vertex.low = self.time
-        self.time+=1
+        self.time += 1
         stack.append(vertex.id)
-        vertex.stackMember=True
+        vertex.stackMember = True
 
         for vID in vertex.refs:
             other_vertex = self.vertices[vID]
             if other_vertex.disc == -1:
                 self._sccutil(other_vertex, stack)
-                vertex.low=min(vertex.low,other_vertex.low)
+                vertex.low = min(vertex.low, other_vertex.low)
             else:
-                vertex.low=min(vertex.low,other_vertex.disc)
-        w=-1
+                vertex.low = min(vertex.low, other_vertex.disc)
+        w = -1
         if vertex.low == vertex.disc:
-            cycle=[]
-            while w!=vertex.id:
+            cycle = []
+            while w != vertex.id:
                 w = stack.pop()
                 cycle += [w]
-                self.vertices[w].stackMember=False
+                self.vertices[w].stackMember = False
             self.cycles += [cycle]
 
     def SCC(self):
-        stack=[]
+        stack = []
         for vertex in self.vertices.values():
             if vertex.disc == -1:
                 self._sccutil(vertex, stack)
 
+
 class BuildMaestro:
-    ALL_TYPES = {}
+    # ALL_TYPES = {}
 
     def __init__(self, hidden_build_dir='.build'):
         self.alltargets: List[BuildTarget] = []
@@ -113,7 +110,7 @@ class BuildMaestro:
         self.all_targets_file: str = os.path.join(self.builddir, 'all_targets.yml')
 
         # This will get Maestro to delete the listed directories, if they are present during --clean.
-        self.other_dirs_to_clean=[]
+        self.other_dirs_to_clean: List[str] = []
 
         self.args: argparse.Namespace = None
 
@@ -136,7 +133,7 @@ class BuildMaestro:
     def generateVirtualTarget(self, id: str) -> str:
         '''
         Usage:
-        
+
         bm.add(CopyFilesTarget(target=bm.generateVirtualTarget('a'),...))
         '''
         return os.path.join(self.builddir, '.targets', id)
@@ -179,7 +176,7 @@ class BuildMaestro:
             with open(self.all_targets_file, 'r', encoding='utf-8') as f:
                 try:
                     older_files = set(sorted(yaml.load(f)))
-                except:
+                except BaseException:
                     older_files = []
         for bt in self.alltargets:
             bt.maestro = self
@@ -209,31 +206,32 @@ class BuildMaestro:
 
     @staticmethod
     def RecognizeType(cls):
-        BuildMaestro.ALL_TYPES[cls.BT_TYPE] = cls
+        #BuildMaestro.ALL_TYPES[cls.BT_TYPE] = cls
+        pass
 
-    def saveRules(self, filename):
-        serialized = {}
-        for rule in self.alltargets:
-            serialized[rule.name] = rule.serialize()
-        with codecs.open(filename + '.yml', 'w', encoding='utf-8') as f:
-            yaml.indent()
-            yaml.dump(serialized, f)
-        with codecs.open(filename, 'w', encoding='utf-8') as f:
-            for tKey in sorted(serialized.keys()):
-                target = dict(serialized[tKey])
-                f.write(u'[{} {}]: {}\n'.format(target['type'], tKey, ', '.join(target.get('dependencies', []))))
-                del target['dependencies']
-                for provided in target.get('provides', []):
-                    if provided != tKey:
-                        f.write(u'< {}\n'.format(provided))
-                for depend in target.get('files', []):
-                    f.write(u'> {}\n'.format(depend))
-                del target['files']
-                del target['type']
-                if len(target.keys()) > 0:
-                    yaml.indent()
-                    yaml.dump(target, f)
-                f.write(u'\n')
+    # def saveRules(self, filename):
+    #     serialized = {}
+    #     for rule in self.alltargets:
+    #         serialized[rule.name] = rule.serialize()
+    #     with codecs.open(filename + '.yml', 'w', encoding='utf-8') as f:
+    #         yaml.indent()
+    #         yaml.dump(serialized, f)
+    #     with codecs.open(filename, 'w', encoding='utf-8') as f:
+    #         for tKey in sorted(serialized.keys()):
+    #             target = dict(serialized[tKey])
+    #             f.write(u'[{} {}]: {}\n'.format(target['type'], tKey, ', '.join(target.get('dependencies', []))))
+    #             del target['dependencies']
+    #             for provided in target.get('provides', []):
+    #                 if provided != tKey:
+    #                     f.write(u'< {}\n'.format(provided))
+    #             for depend in target.get('files', []):
+    #                 f.write(u'> {}\n'.format(depend))
+    #             del target['files']
+    #             del target['type']
+    #             if len(target.keys()) > 0:
+    #                 yaml.indent()
+    #                 yaml.dump(target, f)
+    #             f.write(u'\n')
 
     # def loadRules(self, filename):
     #     REGEX_RULEHEADER = re.compile('\[([A-Za-z0-9]+) ([^:]+)\]:(.*)$')
@@ -299,21 +297,21 @@ class BuildMaestro:
                 refs = []
                 for depend in bt.dependencies:
                     if not isinstance(depend, str):
-                        log.critical('Build target %s has invalid dependency %s.',bt.name,depend)
+                        log.critical('Build target %s has invalid dependency %s.', bt.name, depend)
                         sys.exit(1)
-                    providers=[]
+                    providers = []
                     for obt in self.alltargets:
                         if depend in obt.provides():
                             #log.info('%s provides %s, which %s needs', obt.name, depend, bt.name)
                             providers += [obt]
                     if len(providers) > 1:
-                        log.warning('Build target %s has %d providers for dependency %s: %r',bt.name,len(providers),depend,[x.name for x in providers])
+                        log.warning('Build target %s has %d providers for dependency %s: %r', bt.name, len(providers), depend, [x.name for x in providers])
                     elif len(providers) == 0:
-                        log.critical('Build target %s has no providers for dependency %s: %r',bt.name,depend,[x.name for x in providers])
+                        log.critical('Build target %s has no providers for dependency %s: %r', bt.name, depend, [x.name for x in providers])
                         sys.exit(1)
                     refs.append(providers[-1].id)
                 with log.debug('Dependency tree:'):
-                    with log.debug('[%s] (%d,[%s])',bt.name,bt.id,', '.join([str(x) for x in refs])):
+                    with log.debug('[%s] (%d,[%s])', bt.name, bt.id, ', '.join([str(x) for x in refs])):
                         for refID in refs:
                             log.debug(self.alltargets[refID].name)
                 tg.add_edge(bt.id, refs)
@@ -322,11 +320,11 @@ class BuildMaestro:
             tg.SCC()
 
             # Sort through the crap that falls out
-            foundCycles=False
+            foundCycles = False
             for cycle in tg.cycles:
                 if len(cycle) > 1:
-                    log.critical('CYCLE FOUND: %r', ['#{} ({})'.format(self.alltargets[btid].id,self.alltargets[btid].name) for btid in cycle])
-                    foundCycles=True
+                    log.critical('CYCLE FOUND: %r', ['#{} ({})'.format(self.alltargets[btid].id, self.alltargets[btid].name) for btid in cycle])
+                    foundCycles = True
             return foundCycles
 
     def _write_targets(self):
@@ -339,11 +337,11 @@ class BuildMaestro:
         with open(self.all_targets_file, 'w', encoding='utf-8') as f:
             yaml.dump(list(alltargets), f)
 
-    def run(self, verbose=None):
+    def run(self, verbose: Optional[bool] = None):
         if verbose is not None:
             self.verbose = verbose
 
-        new_targets=[]
+        new_targets = []
         for t in self.targets:
             if t in new_targets:
                 log.warn('Target %s added more than once.', t)
@@ -353,14 +351,14 @@ class BuildMaestro:
         if self.checkForCycles():
             return
         keys = []
-        alldeps=[]
+        alldeps = []
         for target in self.alltargets:
             keys += target.provides()
             alldeps += target.dependencies
-            target.built=False
-        alldeps=list(set(alldeps))
+            target.built = False
+        alldeps = list(set(alldeps))
         # Redundant
-        #for target in self.alltargets:
+        # for target in self.alltargets:
         #    for reqfile in callLambda(target.files):
         #        if reqfile in keys and reqfile not in target.dependencies:
         #            target.dependencies.append(reqfile)
@@ -390,23 +388,23 @@ class BuildMaestro:
                         self._write_targets()
                         log.critical('Cancelled via KeyboardInterrupt.')
                         return
-                    bt.built=True
-            log.debug('%d > %d, loop = %d',len(self.targets), len(self.targetsCompleted), loop)
-        log.debug('%d > %d, loop = %d',len(self.targets), len(self.targetsCompleted), loop)
+                    bt.built = True
+            log.debug('%d > %d, loop = %d', len(self.targets), len(self.targetsCompleted), loop)
+        log.debug('%d > %d, loop = %d', len(self.targets), len(self.targetsCompleted), loop)
         # progress.close()
         self._write_targets()
         if loop >= 100:
-            incompleteTargets=[t for t in self.targets if t not in self.targetsCompleted]
-            if len(incompleteTargets)>0:
+            incompleteTargets = [t for t in self.targets if t not in self.targetsCompleted]
+            if len(incompleteTargets) > 0:
                 with log.critical("Failed to resolve dependencies.  The following targets are left unresolved. Exiting."):
                     for t in incompleteTargets:
                         log.critical(t)
-            orphanDeps=[t for t in alldeps if t not in self.targets]
-            if len(orphanDeps)>0:
+            orphanDeps = [t for t in alldeps if t not in self.targets]
+            if len(orphanDeps) > 0:
                 with log.critical("Failed to resolve dependencies.  The following dependencies are orphaned. Exiting."):
                     for t in orphanDeps:
                         log.critical(t)
-            #sys.exit(1)
+            # sys.exit(1)
         with log.info('Cleaning up...'):
             cachefiles = []
             for bt in self.alltargets:
