@@ -85,8 +85,12 @@ class NuitkaTarget(SingleBuildTarget):
         self.included_packages: Set[str] = set()
         self.enabled_plugins: Set[str] = set()
         self._always_active_plugins: Set[str] = set()
-
         self._always_active_plugins = self.getAlwaysActivePluginNames()
+        self.recurse_none: bool = False
+        self.recurse_to: List[str] = []
+        self.pgo: bool = False
+        self.lto: bool = False
+        self.python_flags: str=''
 
     def get_config(self) -> Dict[str, Any]:
         return super().get_config()
@@ -116,13 +120,24 @@ class NuitkaTarget(SingleBuildTarget):
             # '--follow-imports',
         ]
         if os.name != 'nt':
-            opts += ['--static-libpython=yes']
+            opts.append('--static-libpython=yes')
+        if self.recurse_none:
+            opts.append('--recurse-none')
+        if len(self.recurse_to)>0:
+            #opts.append(f'--recurse-to='+(','.join(self.recurse_to)))
+            opts += [f'--recurse-to={x}' for x in self.recurse_to]
         for pkg in sorted(self.included_packages):
-            opts += [f'--include-package={pkg}']
-        #print('ENABLED', repr(self.enabled_plugins))
-        #print('ALWAYS', repr(self._always_active_plugins))
+            opts.append(f'--include-package={pkg}')
+        # print('ENABLED', repr(self.enabled_plugins))
+        # print('ALWAYS', repr(self._always_active_plugins))
         for plug in sorted(self.enabled_plugins - self._always_active_plugins):
-            opts += [f'--enable-plugin={plug}']
+            opts.append(f'--enable-plugin={plug}')
+        if self.lto:
+            opts.append('--lto=yes')
+        if self.pgo:
+            opts.append('--pgo')
+        if len(self.python_flags)>0:
+            opts.append('--python-flags='+self.python_flags)
         opts += [
             f'--output-dir={self.out_dir}',
             # '--show-progress', # *screaming*
