@@ -22,18 +22,33 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 
 '''
+from __future__ import annotations
+
 import codecs
-import os
-import re
-import json
 import enum
-import requests
 import hashlib
-from urllib.request import urlparse
-from buildtools import log, os_utils, utils, http
+import json
+import os
+from pathlib import Path
+import re
+from typing import List, Optional
+
+from buildtools.types import StrOrPath
+
+try:
+    from urllib.parse import urlparse
+except ImportError:
+    from urllib.request import urlparse
+
+import requests
+
+from buildtools import http, log, os_utils, utils
+from buildtools.maestro import BuildMaestro
 from buildtools.maestro.base_target import SingleBuildTarget
 
 REG_SCSS_IMPORT = re.compile(r"@import '([^']+)';")
+
+
 class _BaseSCSSBuildTarget(SingleBuildTarget):
     def __init__(self, target=None, files=[], dependencies=[], import_paths=[], output_style='compact', sass_path=None, imported=[]):
         super().__init__(target, files, dependencies)
@@ -45,29 +60,29 @@ class _BaseSCSSBuildTarget(SingleBuildTarget):
         self.sass_path = sass_path
 
     def getFilesToCompare(self):
-        o = super().getFilesToCompare()+self.imported
+        o = super().getFilesToCompare() + self.imported
         for filename in self.files:
             o += self.detectFilesImportedBy(filename)
         return list(set(o))
 
     def detectFilesImportedBy(self, filename):
-        imports=[]
+        imports = []
         DIR_CONTEXT = os.path.abspath(os.path.dirname(filename))
         with open(filename, 'r') as f:
             for line in f:
-                line=line.strip()
+                line = line.strip()
                 m = REG_SCSS_IMPORT.match(line)
                 if m is not None:
-                    for context in [DIR_CONTEXT]+self.import_paths:
+                    for context in [DIR_CONTEXT] + self.import_paths:
                         unprefixed_filename = os.path.join(context, m.group(1))
                         dirname = os.path.dirname(unprefixed_filename)
-                        prefixed_basename = '_'+os.path.basename(unprefixed_filename)+'.scss'
+                        prefixed_basename = '_' + os.path.basename(unprefixed_filename) + '.scss'
                         prefixed_filename = os.path.join(dirname, prefixed_basename)
                         if os.path.isfile(prefixed_filename):
                             imports += [prefixed_filename]
                             imports += self.detectFilesImportedBy(prefixed_filename)
                             break
-        if len(imports)==0:
+        if len(imports) == 0:
             log.debug('%s imported 0 files.', filename)
         else:
             with log.debug('%s imported %d files:', filename, len(imports)):
@@ -97,6 +112,7 @@ class _BaseSCSSBuildTarget(SingleBuildTarget):
             'imported': self.imported
         }
 
+
 class DartSCSSBuildTarget(_BaseSCSSBuildTarget):
     BT_TYPE = 'DART-SCSS'
     BT_LABEL = 'DART SCSS'
@@ -125,6 +141,7 @@ class DartSCSSBuildTarget(_BaseSCSSBuildTarget):
         os_utils.ensureDirExists(os.path.dirname(self.target))
         os_utils.cmd(sass_cmd + args + self.files + [self.target], critical=True, echo=self.should_echo_commands(), show_output=True)
 
+
 class RubySCSSBuildTarget(_BaseSCSSBuildTarget):
     BT_TYPE = 'RUBY-SCSS'
     BT_LABEL = 'RUBY SCSS'
@@ -138,7 +155,7 @@ class RubySCSSBuildTarget(_BaseSCSSBuildTarget):
         self.compass = compass
 
     def getFilesToCompare(self):
-        return super().getFilesToCompare()+self.imported
+        return super().getFilesToCompare() + self.imported
 
     def serialize(self):
         dat = super().serialize()
@@ -265,7 +282,7 @@ class UglifyJSTarget(SingleBuildTarget):
         super(UglifyJSTarget, self).__init__(target, files=[inputfile], dependencies=dependencies)
 
     def get_config(self):
-        return {'path': self.uglifyjs_executable, 'opts':self.options}
+        return {'path': self.uglifyjs_executable, 'opts': self.options}
 
     def build(self):
         cmdline = [self.uglifyjs_executable] + self.options + ['-o', self.target, self.files[0]]
@@ -295,6 +312,8 @@ class MinifySVGTarget(SingleBuildTarget):
 
 
 REG_IMAGEURL = re.compile(r'url\("([^"]+)"\)')
+
+
 def convert_imgurls_to_dataurls(infile, outfile, basedir):
     def _convert_img2data(m):
         # log.info(m.group(0))
@@ -320,27 +339,36 @@ class DatafyImagesTarget(SingleBuildTarget):
     def build(self):
         convert_imgurls_to_dataurls(self.infile, self.target, self.basedir)
 
+
 class EBashLayoutFlags(enum.IntFlag):
-    PREFIX   = 1
-    NAME     = 2
-    HASHDIR  = 4
+    PREFIX = 1
+    NAME = 2
+    HASHDIR = 4
     HIDENAME = 8
 
+
 class CacheBashifyFiles(SingleBuildTarget):
     BT_TYPE = 'CacheBashify'
     BT_LABEL = 'CACHE BASH'
 
     CHECK_MTIMES = False
 
-    def __init__(self, destdir, source, manifest, basedirsrc='.', basedirdest=None, dependencies=[], flags=None):
-        self.source      = source
-        self.destdir     = destdir
-        self.basedirsrc  = basedirsrc
-        self.basedirdest = basedirdest
-        self.manifest    = manifest
-        self.flags       = flags if flags is not None else (EBashLayoutFlags.PREFIX|EBashLayoutFlags.NAME)
-        target = self.genVirtualTarget(self.source.replace(os.sep, '_').replace('.','_'))
-        super().__init__(target=target, dependencies=dependencies, files=[source, os.path.abspath(__file__)])
+    def __init__(self,
+                 bm: BuildMaestro,
+                 destdir: str,
+                 source: str,
+                 manifest: str,
+                 basedirsrc: str = '.',
+                 basedirdest: Optional[str] = None,
+                 dependencies: List[str] = [],
+                 flags: Optional[EBashLayoutFlags] = None) -> None:
+        self.source: str = source
+        self.destdir: str = destdir
+        self.basedirsrc: str = basedirsrc
+        self.basedirdest: Optional[str] = basedirdest
+        self.manifest: str = manifest
+        self.flags = flags if flags is not None else (EBashLayoutFlags.PREFIX | EBashLayoutFlags.NAME)
+        super().__init__(target=self.genVirtualTarget(bm), dependencies=dependencies, files=[source, os.path.abspath(__file__)])
 
     def get_config(self):
         return {
@@ -352,7 +380,7 @@ class CacheBashifyFiles(SingleBuildTarget):
         }
 
     def clean(self):
-        manifest_data={}
+        manifest_data = {}
         if os.path.isfile(self.manifest):
             with open(self.manifest, 'r') as f:
                 manifest_data = json.load(f)
@@ -367,7 +395,7 @@ class CacheBashifyFiles(SingleBuildTarget):
         dirname = os.path.dirname(sourcefilerel)
         basename, ext = os.path.splitext(os.path.basename(sourcefilerel))
         if basename.endswith('.min'):
-            basename=basename[:-4]
+            basename = basename[:-4]
             ext = f'.min{ext}'
 
         newbnparts = []
@@ -428,7 +456,7 @@ class CacheBashifyFiles(SingleBuildTarget):
         sourcefilerel = sourcefilerel.replace(os.sep, '/')
         outfile = reloutfile.replace(os.sep, '/')
 
-        manifest_data={
+        manifest_data = {
             sourcefilerel: outfile
         }
         if os.path.isfile(self.manifest):
@@ -437,8 +465,8 @@ class CacheBashifyFiles(SingleBuildTarget):
 
         if sourcefilerel in manifest_data.keys():
             oldfilename = os.path.normpath(os.path.join(self.destdir, manifest_data[sourcefilerel]))
-            #log.info(oldfilename)
-            #log.info(absoutfile)
+            # log.info(oldfilename)
+            # log.info(absoutfile)
             if oldfilename != absoutfile:
                 self.removeFile(oldfilename)
 
@@ -448,12 +476,13 @@ class CacheBashifyFiles(SingleBuildTarget):
         manifest_data[sourcefilerel] = outfile
 
         os_utils.ensureDirExists(os.path.dirname(self.manifest), noisy=True)
-        #print(self.manifest)
+        # print(self.manifest)
         with open(self.manifest, 'w') as f:
             json.dump(manifest_data, f, indent=2)
         self.touch(absoutfile)
         self.touch(self.target)
 
+
 class DownloadFileTarget(SingleBuildTarget):
     BT_TYPE = 'DownloadFile'
     BT_LABEL = 'DOWNLOAD'
@@ -472,21 +501,21 @@ class DownloadFileTarget(SingleBuildTarget):
         self.etagfile: str = ''
         super().__init__(target, dependencies=dependencies, files=[url, os.path.abspath(__file__)])
 
-
     def get_displayed_name(self):
         return '{} -> {}'.format(self.url, self.target)
 
-    def _updateCacheInfo(self) -> str:
+    def _updateCacheInfo(self) -> None:
+        assert self.maestro is not None
         self.cache_dir = os.path.join(self.maestro.builddir, 'DownloadFileTarget.cache')
 
         fileid = hashlib.md5(self.urlchunks.path.encode('utf-8')).hexdigest()
 
         self.etagdir = os.path.join(self.cache_dir, self.urlchunks.hostname, fileid[0:2], fileid[2:4])
         #self.old_uri_id = hashlib.sha256(self.urlchunks.path.encode('utf-8')).hexdigest()+'.etags'
-        uri_id = fileid[4:]+'.etags'
-        self.cached_dl = os.path.join(self.etagdir, fileid[4:]+'.dat')
+        uri_id = fileid[4:] + '.etags'
+        self.cached_dl = os.path.join(self.etagdir, fileid[4:] + '.dat')
 
-        #if os.path.isfile(os.path.join(etagdir, old_uri_id)):
+        # if os.path.isfile(os.path.join(etagdir, old_uri_id)):
         #    shutil.move(os.path.join(etagdir, old_uri_id), os.path.join(etagdir, uri_id))
 
         self.etagfile = os.path.join(self.etagdir, uri_id)
@@ -503,7 +532,7 @@ class DownloadFileTarget(SingleBuildTarget):
             with open(self.etagfile, 'r') as f:
                 etag = f.read()
         with log.info('Checking for changes to %s...', self.url):
-            res = requests.head(self.url, allow_redirects=True, headers={'If-None-Match':etag})
+            res = requests.head(self.url, allow_redirects=True, headers={'If-None-Match': etag})
             if res.status_code == 304:
                 log.info('304 - Not Modified')
                 return False
@@ -526,10 +555,6 @@ class DownloadFileTarget(SingleBuildTarget):
         if not self.cache:
             os.remove(self.cached_dl)
 
-import os
-from buildtools import os_utils
-from buildtools.maestro.base_target import SingleBuildTarget
-
 
 class WebifyTarget(SingleBuildTarget):
     BT_TYPE = 'Webify'
@@ -554,8 +579,8 @@ class WebifyTarget(SingleBuildTarget):
         }
 
     def provides(self):
-        base,_ = os.path.splitext(self.intermediate_filename)
-        o=[]
+        base, _ = os.path.splitext(self.intermediate_filename)
+        o = []
         for ext in ['eot', 'woff', 'ttf', 'svg']:
             o += [base + '.' + ext]
         return o
